==> haskell-hspec-smallcheck-0.5.3-143-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-smallcheck
version:              0.5.3
visibility:           public
id:                   hspec-smallcheck-0.5.3-KVCNPmSBsiSJ8Mt1O0xxaF
key:                  hspec-smallcheck-0.5.3-KVCNPmSBsiSJ8Mt1O0xxaF
license:              MIT
copyright:            (c) 2013-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             http://hspec.github.io/
synopsis:             SmallCheck support for the Hspec testing framework
description:          SmallCheck support for the Hspec testing framework
category:             Testing
abi:                  4d86a1b80ccff81acabd43559559cf4f
exposed:              True
exposed-modules:      Test.Hspec.SmallCheck
hidden-modules:
    Test.Hspec.SmallCheck.Compat Test.Hspec.SmallCheck.Types
    Paths_hspec_smallcheck

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-smallcheck-0.5.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-smallcheck-0.5.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-smallcheck-0.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-smallcheck
hs-libraries:         HShspec-smallcheck-0.5.3-KVCNPmSBsiSJ8Mt1O0xxaF
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA base-4.18.2.1
    call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
    hspec-core-2.11.4-LH4ljAyFr7833CkU966kHA
    smallcheck-1.2.1.1-1IgojUhwjusBuCDUS7RhYP

haddock-interfaces:
    /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-smallcheck-0.5.3-144-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-smallcheck
version:              0.5.3
visibility:           public
id:                   hspec-smallcheck-0.5.3-6G3yPARKi16LZ6CGIUDmLY
key:                  hspec-smallcheck-0.5.3-6G3yPARKi16LZ6CGIUDmLY
license:              MIT
copyright:            (c) 2013-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             http://hspec.github.io/
synopsis:             SmallCheck support for the Hspec testing framework
description:          SmallCheck support for the Hspec testing framework
category:             Testing
abi:                  74b28efd034ef9ef282dcbfb293ddc26
exposed:              True
exposed-modules:      Test.Hspec.SmallCheck
hidden-modules:
    Test.Hspec.SmallCheck.Compat Test.Hspec.SmallCheck.Types
    Paths_hspec_smallcheck

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-smallcheck-0.5.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-smallcheck-0.5.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-smallcheck-0.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-smallcheck
hs-libraries:         HShspec-smallcheck-0.5.3-6G3yPARKi16LZ6CGIUDmLY
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA base-4.18.2.1
    call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
    hspec-core-2.11.4-K7WhEYoVaEl4ISGwW2E5jD
    smallcheck-1.2.1.1-FY3F5Byduyr9XO70wpy508

haddock-interfaces:
    /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
